@@ -9,7 +9,7 @@ import traceback
 import re
 import random
 import base64
-import html as html_decode
+import html
 from colorama import Fore
 from tqdm import tqdm as td
 
@@ -469,7 +469,7 @@ video_pojie = lambda url: 'http://okjx.cc/?url=' + url
 :return: Type == str
 """
 
-html_node_text = lambda HTML, XPATH: html_decode.unescape(
+html_node_text = lambda HTML, XPATH: html.unescape(
     html_clean(str(etree.tostring(etree.HTML(HTML).xpath(XPATH)[0])))).lstrip("b'").rstrip("'")
 """
 单节点方法，xpath列表请调用html_nodes_text方法
@@ -486,7 +486,7 @@ def html_nodes_text(XPATH_list):
     """
     text_list = []
     for Xpath in XPATH_list:
-        result = html_decode.unescape(html_clean(str(etree.tostring(Xpath)))).lstrip("b'").rstrip("'")
+        result = html.unescape(html_clean(str(etree.tostring(Xpath)))).lstrip("b'").rstrip("'")
         text_list.append(result)
     return text_list
 
